@@ -76,8 +76,8 @@ pub fn run(jobs: Vec<Job>) -> Vec<Job> {
                                             &n, &results, &jobs
                                         )
                                     });
-                                    is_result_settled(&needed_result)
-                                        && !is_result_done(&needed_result)
+                                    is_result_settled(needed_result)
+                                        && !is_result_done(needed_result)
                                 });
                                 if is_now_blocked {
                                     results.insert(name.clone(), Ok(Status::Blocked));
@@ -207,7 +207,7 @@ mod tests {
     where
         S: AsRef<str>,
     {
-        jobs.remove(job_position(&jobs, name.as_ref()))
+        jobs.remove(job_position(jobs, name.as_ref()))
     }
 
     fn job_position<S>(jobs: &[Job], name: S) -> usize
@@ -341,7 +341,7 @@ mod tests {
         jobs = run(jobs);
 
         for job in &jobs {
-            assert_executed(&job);
+            assert_executed(job);
             let i = job.name().parse::<usize>().unwrap_or_else(|err| {
                 panic!("could not parse '{}' as usize: {:?}", job.name(), err)
             });
